@@ -21,8 +21,10 @@ class IntentType(Enum):
     QUANTUM_FOURIER = "qft"
     GROVER_SEARCH = "grover"
     VQE_OPTIMIZATION = "vqe"
-    PROTEIN_FOLDING = "protein_folding"
+    # IMPORTANT: DRUG_DOCKING before PROTEIN_FOLDING
+    # because docking has more specific keywords (SMILES, PDB)
     DRUG_DOCKING = "drug_docking"
+    PROTEIN_FOLDING = "protein_folding"
     DNA_ANALYSIS = "dna_analysis"
     MOLECULAR_SIMULATION = "molecular_sim"
     MEASURE_QUBITS = "measurement"
@@ -268,10 +270,12 @@ class MegaPatternMatcher:
             return self._match_entanglement(text)
         elif intent == IntentType.QUANTUM_FOURIER:
             return self._match_qft(text)
-        elif intent == IntentType.PROTEIN_FOLDING:
-            return self._match_protein_folding(text)
+        # IMPORTANT: Check DRUG_DOCKING before PROTEIN_FOLDING
+        # because docking keywords (SMILES, PDB, binding) are more specific
         elif intent == IntentType.DRUG_DOCKING:
             return self._match_drug_docking(text)
+        elif intent == IntentType.PROTEIN_FOLDING:
+            return self._match_protein_folding(text)
         elif intent == IntentType.DNA_ANALYSIS:
             return self._match_dna_analysis(text)
         elif intent == IntentType.MEASURE_QUBITS:
@@ -379,7 +383,19 @@ class MegaPatternMatcher:
         return None
 
     def _match_drug_docking(self, text: str) -> Optional[PatternMatch]:
-        """Match drug docking patterns."""
+        """Match drug docking patterns - checks for SMILES, PDB, docking keywords."""
+        # HIGH PRIORITY: Check for SMILES or PDB mentions (very specific to docking)
+        if 'smiles' in text or 'pdb' in text:
+            if 'dock' in text or 'binding' in text or 'affinity' in text or 'receptor' in text or 'ligand' in text:
+                num_qubits = self._extract_number(text) or 6
+                return PatternMatch(
+                    intent=IntentType.DRUG_DOCKING,
+                    confidence=0.98,  # Very high confidence for SMILES/PDB
+                    extracted_params={'num_qubits': num_qubits},
+                    original_text=text
+                )
+
+        # NORMAL PRIORITY: Check for drug + binding terms
         for verb_list in self.action_verbs['simulate'] + self.action_verbs['analyze']:
             for drug_term in self.domain_terms['drug']:
                 for binding_term in self.domain_terms['binding']:
